Stage class

The local state of the novel.

A new object of Stage is created when a scene changes.

Mixed-in types

Constructors

Stage({required AudioManager audio})

Properties

audio → AudioManager
final
background Widget?
no setter
characters Set<Character>
no setter
choices Set<Choice>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typewritingState ↔ TypewritingStates
Once a new scene is shown, its verse is animated.
getter/setter pair
verse Verse?
no setter
verseHistory List<Verse>
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispatchEvent(NovelInputEvent event) → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setBackground(Widget background) → void
setVerse(Verse? verse) → void
showChoices(Set<Choice> choices) → void
toString() String
A string representation of this object.
inherited
waitForInput() Future<NovelInputEvent>
Rebuilds the stage according to provided changes, then waits for user input (usually screen tap). If the user input is a choice, returns a DialogOptionEvent so you can read the result.

Operators

operator ==(Object other) bool
The equality operator.
inherited